/*
 * Copyright (c) 2016 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/*global window*/

/**
 * Application UI creator option module.
 * It is responsible for managing UI content,
 * displaying notification option details.
 *
 * @module app.ui.creator.option
 * @requires {@link app.ui.creator.option.basic}
 * @requires {@link app.ui.creator.option.icons}
 * @requires {@link app.ui.creator.option.repeat}
 * @requires {@link app.ui.creator.option.led}
 * @requires {@link app.ui.creator.option.sound}
 * @requires {@link app.ui.creator.option.vibration}
 * @requires {@link app.ui.creator.option.progress}
 * @requires {@link app.ui.creator.option.details}
 * @requires {@link app.ui.creator.option.action}
 * @namespace app.ui.creator.option
 * @memberof app.ui.creator
 */

// make sure that "app" namespace is created
window.app = window.app || {};

(function defineAppUiCreatorOption(app) {
    'use strict';

    /**
     * UI creator option basic module reference.
     *
     * @memberof app.ui.creator.option
     * @private
     * @type {object}
     */
    var uiCreatorOptionBasic = app.ui.creator.option.basic,

        /**
         * UI creator option icons module reference.
         *
         * @memberof app.ui.creator.option
         * @private
         * @type {object}
         */
        uiCreatorOptionIcons = app.ui.creator.option.icons,

        /**
         * UI creator option repeat module reference.
         *
         * @memberof app.ui.creator.option
         * @private
         * @type {object}
         */
        uiCreatorOptionRepeat = app.ui.creator.option.repeat,

        /**
         * UI creator option led module reference.
         *
         * @memberof app.ui.creator.option
         * @private
         * @type {object}
         */
        uiCreatorOptionLed = app.ui.creator.option.led,

        /**
         * UI creator option sound module reference.
         *
         * @memberof app.ui.creator.option
         * @private
         * @type {object}
         */
        uiCreatorOptionSound = app.ui.creator.option.sound,

        /**
         * UI creator option vibration module reference.
         *
         * @memberof app.ui.creator.option
         * @private
         * @type {object}
         */
        uiCreatorOptionVibration = app.ui.creator.option.vibration,

        /**
         * UI creator option progress module reference.
         *
         * @memberof app.ui.creator.option
         * @private
         * @type {object}
         */
        uiCreatorOptionProgress = app.ui.creator.option.progress,

        /**
         * UI creator option details module reference.
         *
         * @memberof app.ui.creator.option
         * @private
         * @type {object}
         */
        uiCreatorOptionDetails = app.ui.creator.option.details,

        /**
         * UI creator option action module reference.
         *
         * @memberof app.ui.creator.option
         * @private
         * @type {object}
         */
        uiCreatorOptionAction = app.ui.creator.option.action;

    /**
     * Handles option.changed event.
     *
     * @memberof app.ui.creator.option
     * @private
     * @param {Event} ev
     */
    function onOptionChanged(ev) {
        switch (ev.detail.name) {
            case 'icons-option':
                uiCreatorOptionIcons.show();
                break;
            case 'repeat-option':
                uiCreatorOptionRepeat.show();
                break;
            case 'led-option':
                uiCreatorOptionLed.show();
                break;
            case 'sound-option':
                uiCreatorOptionSound.show();
                break;
            case 'vibration-option':
                uiCreatorOptionVibration.show();
                break;
            case 'progress-option':
                uiCreatorOptionProgress.show();
                break;
            case 'details-option':
                uiCreatorOptionDetails.show();
                break;
            case 'action-option':
                uiCreatorOptionAction.show();
                break;
            default:
                uiCreatorOptionBasic.show();
        }
    }

    /**
     * Registers event listeners.
     *
     * @memberof app.ui.creator.option
     * @private
     */
    function bindEvents() {
        window.addEventListener('option.changed', onOptionChanged);
    }

    /**
     * Initializes the UI creator option module.
     *
     * @memberof app.ui.creator.option
     * @public
     */
    function init() {
        uiCreatorOptionBasic.init();
        uiCreatorOptionIcons.init();
        uiCreatorOptionRepeat.init();
        uiCreatorOptionLed.init();
        uiCreatorOptionSound.init();
        uiCreatorOptionVibration.init();
        uiCreatorOptionProgress.init();
        uiCreatorOptionDetails.init();
        uiCreatorOptionAction.init();
        bindEvents();
    }

    app.ui = app.ui || {};
    app.ui.creator = app.ui.creator || {};
    app.ui.creator.option = {
        init: init
    };

})(window.app);
